searchData={"items":[{"type":"module","title":"MjmlEEx","doc":"Documentation for `MjmlEEx` template module. This moule contains the macro\nthat is used to create an MJML EEx template. The macro can be configured to\nrender the MJML template in a few different ways, so be sure to read the\noption documentation.","ref":"MjmlEEx.html"},{"type":"module","title":"Macro Options - MjmlEEx","doc":"- `:mjml_template`- A binary that specifies the name of the `.mjml.eex` template that the module will compile. The\n  directory path is relative to the template module. If this option is not provided, the MjmlEEx will look for a\n  file that has the same name as the module but with the `.mjml.ex` extension as opposed to `.ex`.\n\n- `:mode`- This option defines when the MJML template is actually compiled. The possible values are `:runtime` and\n  `:compile`. When this option is set to `:compile`, the MJML template is compiled into email compatible HTML at\n  compile time. It is suggested that this mode is only used if the template is relatively simple and there are only\n  assigns being used as text or attributes on html elements (as opposed to attributes on MJML elements). The reason\n  for that being that these assigns may be discarded as part of the MJML compilation phase. On the plus side, you\n  do get a performance bump here since the HTML for the email is already generated. When this is set to `:runtime`,\n  the MJML template is compiled at runtime and all the template assigns are applied prior to the MJML compilation\n  phase. These means that there is a performance hit since you are compiling the MJML template every time, but the\n  template can use more complex EEx constructs like `for`, `case` and `cond`. The default configuration is `:runtime`.\n\n- `:layout` - This option defines what layout the template should be injected into prior to rendering the template.\n  This is useful if you want to have reusable email templates in order to keep your email code DRY and reusable.\n  Your template will then be injected into the layout where the layout defines `<%= inner_content %>`.","ref":"MjmlEEx.html#module-macro-options"},{"type":"module","title":"Example Usage - MjmlEEx","doc":"You can use this module like so:\n\n```elixir\ndefmodule BasicTemplate do\n  use MjmlEEx, mjml_template: \"basic_template.mjml.eex\"\nend\n```\n\nAlong with the `basic_template.mjml.eex MJML` template located in the same\ndirectory as the module containing the following:\n\n```html\n \n   \n     \n       \n          \n         Hello <%= @first_name %> <%= @last_name %>! \n       \n     \n   \n \n```\n\nOnce that is in place, you can render the final HTML document by running:\n\n```elixir\nBasicTemplate.render(first_name: \"Alex\", last_name: \"Koutmos\")\n```","ref":"MjmlEEx.html#module-example-usage"},{"type":"function","title":"MjmlEEx.configured_compiler/0","doc":"Get the configured MJML compiler. By default, the `MjmlEEx.Compilers.Rust` compiler\nis used.","ref":"MjmlEEx.html#configured_compiler/0"},{"type":"behaviour","title":"MjmlEEx.Compiler","doc":"This module defines the behaviour that all compiler implementations\nneed to adhere to.","ref":"MjmlEEx.Compiler.html"},{"type":"callback","title":"MjmlEEx.Compiler.compile/1","doc":"","ref":"MjmlEEx.Compiler.html#c:compile/1"},{"type":"module","title":"MjmlEEx.Compilers.Node","doc":"This module implements the `MjmlEEx.Compiler` behaviour\nand allows you to compile your MJML templates using the Node\nCLI tool. This compiler expects you to have the `mjml` Node\nscript accessible from the running environment.\n\nFor information regarding the Node mjml compiler see:\nhttps://documentation.mjml.io/#command-line-interface","ref":"MjmlEEx.Compilers.Node.html"},{"type":"module","title":"Configuration - MjmlEEx.Compilers.Node","doc":"In order to use this compiler, you need to set your application\nconfigration like so (in your `config.exs` file for example):\n\n```elixir\nconfig :mjml_eex,\n  compiler: MjmlEEx.Compilers.Node,\n  compiler_opts: [\n    timeout: 10_000,\n    path: \"mjml\"\n]\n```\n\nIn addition, since the Node compiler is run via `:erlexec`, you will\nneed to add this optional dependency to your `mix.exs` file and also\nstart the optional application:\n\n```elixir\ndef application do\n  [\n    extra_applications: [..., :erlexec]\n  ]\nend\n\ndefp deps do\n  [\n    ...\n    {:erlexec, \"~> 2.0\"}\n  ]\nend\n```","ref":"MjmlEEx.Compilers.Node.html#module-configuration"},{"type":"module","title":"MjmlEEx.Compilers.Rust","doc":"This module implements the `MjmlEEx.Compiler` behaviour\nand allows you to compile your MJML templates using the Rust\nNIF (https://hexdocs.pm/mjml/readme.html).\n\nThis is the default compiler.","ref":"MjmlEEx.Compilers.Rust.html"},{"type":"behaviour","title":"MjmlEEx.Component","doc":"This module allows you to define a reusable MJML component that can be injected into\nan MJML template prior to it being rendered into HTML. There are two different ways\nthat components can be rendered in templates. The first being `render_static_component`\nand the other being `render_dynamic_component`. `render_static_component` should be used\nto render the component when the data provided to the component is known at compile time.\nIf you want to dynamically render a component (make sure that the template is set to\n`mode: :runtime`) with assigns that are passed to the template, then use\n`render_dynamic_component`.","ref":"MjmlEEx.Component.html"},{"type":"behaviour","title":"Example Usage - MjmlEEx.Component","doc":"To use an MjmlEEx component, create an `MjmlEEx.Component` module that looks like so:\n\n```elixir\ndefmodule HeadBlock do\n  use MjmlEEx.Component\n\n  @impl true\n  def render(_opts) do\n    \"\"\"\n     \n       Hello world! \n        \n     \n    \"\"\"\n  end\nend\n```\n\nWith that in place, anywhere that you would like to use the component, you can add:\n`<%= render_static_component HeadBlock %>` in your MJML EEx template.\n\nYou can also pass options to the render function like so:\n\n```elixir\ndefmodule HeadBlock do\n  use MjmlEEx.Component\n\n  @impl true\n  def render(opts) do\n    \"\"\"\n     \n       #{opts[:title]} \n        \n     \n    \"\"\"\n  end\nend\n```\n\nAnd calling it like so: `<%= render_static_component(HeadBlock, title: \"Some really cool title\") %>`","ref":"MjmlEEx.Component.html#module-example-usage"},{"type":"callback","title":"MjmlEEx.Component.render/1","doc":"Returns the MJML markup for the component as a string.","ref":"MjmlEEx.Component.html#c:render/1"},{"type":"module","title":"MjmlEEx.Engines.Mjml","doc":"This Engine is used to compile the MJML template.","ref":"MjmlEEx.Engines.Mjml.html"},{"type":"module","title":"MjmlEEx.Layout","doc":"This module allows you to define an MJML layout so that you\ncan create reusable email skeletons. To use layouts with your\nMJML emails, create a layout template that contains an\n`<%= @inner_content %>` expression in it like so:\n\n```html\n \n   \n     Say hello to card \n      \n     \n        \n        \n        \n     \n   \n\n  <%= @inner_content %>\n \n```\n\nYou can also include additional assigns like `@padding` in this\nexample. Just make sure that you provide that assign when you\nare rendering the final template. With that in place, you can\ndefine a layout module like so\n\n```elixir\ndefmodule BaseLayout do\n  use MjmlEEx.Layout, mjml_layout: \"base_layout.mjml.eex\"\nend\n```\n\nAnd then use it in conjunction with your templates like so:\n\n```elixir\ndefmodule MyTemplate do\n  use MjmlEEx,\n    mjml_template: \"my_template.mjml.eex\",\n    layout: BaseLayout\nend\n```\n\nThen in your template, all you need to provide are the portions that\nyou need to complete the layout:\n\n```html\n \n  ...\n \n```","ref":"MjmlEEx.Layout.html"},{"type":"module","title":"MjmlEEx.Telemetry","doc":"Telemetry integration for event metrics, logging and error reporting.","ref":"MjmlEEx.Telemetry.html"},{"type":"module","title":"Render events - MjmlEEx.Telemetry","doc":"MJML EEx emits the following telemetry events whenever a template is rendered:\n\n* `[:mjml_eex, :render, :start]` - When the rendering process has begun\n* `[:mjml_eex, :render, :stop]` - When the rendering process has successfully completed\n* `[:mjml_eex, :render, :exception]` - When the rendering process resulted in an error\n\nThe render events contain the following measurements and metadata:\n\n| event        | measures       | metadata                                                                                                                       |\n| ------------ | ---------------| ------------------------------------------------------------------------------------------------------------------------------ |\n| `:start`     | `:system_time` | `:compiler`, `:mode`, `:assigns`, `:mjml_template`, `:mjml_template_file`, `:layout_module`                                    |\n| `:stop`      | `:duration`    | `:compiler`, `:mode`, `:assigns`, `:mjml_template`, `:mjml_template_file`, `:layout_module`                                    |\n| `:exception` | `:duration`    | `:compiler`, `:mode`, `:assigns`, `:mjml_template`, `:mjml_template_file`, `:layout_module`, `:kind`, `:reason`, `:stacktrace` |","ref":"MjmlEEx.Telemetry.html#module-render-events"},{"type":"function","title":"MjmlEEx.Telemetry.attach_logger/1","doc":"This function attaches a Telemetry debug handler to MJML EEx so that you can\nsee what emails are being rendered, under what conditions, and what the\nresulting HTML looks like. This is primarily used for debugging purposes\nbut can be modified for use in production if you need to.","ref":"MjmlEEx.Telemetry.html#attach_logger/1"},{"type":"function","title":"MjmlEEx.Telemetry.detach_logger/0","doc":"Detach the debugging logger so that log messages are no longer produced.","ref":"MjmlEEx.Telemetry.html#detach_logger/0"},{"type":"module","title":"MjmlEEx.Utils","doc":"General MJML EEx utils reside here for encoding and decoding\nElixir expressions in MJML EEx templates.","ref":"MjmlEEx.Utils.html"},{"type":"function","title":"MjmlEEx.Utils.decode_eex_expressions/1","doc":"This function finds all of the instances of of encoded EEx expressions\nand decodes them so that when the EEx HTML template is finally\nrendered, the expressions are executed as expected.","ref":"MjmlEEx.Utils.html#decode_eex_expressions/1"},{"type":"function","title":"MjmlEEx.Utils.encode_expression/2","doc":"This function encodes the internals of an MJML EEx document\nso that when it is compiled, the EEx expressions don't break\nthe MJML compiler.","ref":"MjmlEEx.Utils.html#encode_expression/2"},{"type":"function","title":"MjmlEEx.Utils.escape_eex_expressions/1","doc":"This function goes through and espaces all non-special EEx expressions\nso that they do not throw off the the MJML compiler.","ref":"MjmlEEx.Utils.html#escape_eex_expressions/1"},{"type":"extras","title":"README","doc":"Easily create beautiful emails using  MJML  right from Elixir!\n \n\n \n   \n     \n   \n\n   \n     \n   \n\n   \n     \n   \n\n   \n     \n   \n \n\n \n\n# Contents\n\n- [Installation](#installation)\n- [Supporting MJML EEx](#supporting-mjml_eex)\n- [Using MJML EEx](#setting-up-mjml_eex)\n- [Configuration](#configuration)\n- [Attribution](#attribution)","ref":"readme.html"},{"type":"extras","title":"Installation - README","doc":"[Available in Hex](https://hex.pm/packages/mjml_eex), the package can be installed by adding `mjml_eex` to your list of\ndependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:mjml_eex, \"~> 0.12.0\"}\n  ]\nend\n```\n\nDocumentation can be found at [https://hexdocs.pm/mjml_eex](https://hexdocs.pm/mjml_eex).","ref":"readme.html#installation"},{"type":"extras","title":"Supporting MJML EEx - README","doc":"If you rely on this library to generate awesome looking emails for your application, it would much appreciated\nif you can give back to the project in order to help ensure its continued development.\n\nCheckout my [GitHub Sponsorship page](https://github.com/sponsors/akoutmos) if you want to help out!","ref":"readme.html#supporting-mjml-eex"},{"type":"extras","title":"Gold Sponsors - README","doc":"","ref":"readme.html#gold-sponsors"},{"type":"extras","title":"Silver Sponsors - README","doc":"","ref":"readme.html#silver-sponsors"},{"type":"extras","title":"Bronze Sponsors - README","doc":"","ref":"readme.html#bronze-sponsors"},{"type":"extras","title":"Using MJML EEx - README","doc":"","ref":"readme.html#using-mjml-eex"},{"type":"extras","title":"Basic Usage - README","doc":"Add `{:mjml_eex, \"~> 0.7.0\"}` to your `mix.exs` file and run `mix deps.get`. After you have that in place, you\ncan go ahead and create a template module like so:\n\n```elixir\ndefmodule BasicTemplate do\n  use MjmlEEx, mjml_template: \"basic_template.mjml.eex\"\nend\n```\n\nAnd the accompanying MJML EEx template `basic_template.mjml.eex` (note that the path is relative to the calling\nmodule path):\n\n```html\n \n   \n     \n       \n          \n          Hello <%= @first_name %> <%= @last_name %>!  \n       \n     \n   \n \n```\n\nWith those two in place, you can now run `BasicTemplate.render(first_name: \"Alex\", last_name: \"Koutmos\")` and you\nwill get back an HTML document that can be emailed to users.","ref":"readme.html#basic-usage"},{"type":"extras","title":"Using Functions from Template Module - README","doc":"You can also call functions from your template module if they exist in your MJML EEx template using\nthe following module declaration:\n\n```elixir\ndefmodule FunctionTemplate do\n  use MjmlEEx, mjml_template: \"function_template.mjml.eex\"\n\n  defp generate_full_name(first_name, last_name) do\n    \"#{first_name} #{last_name}\"\n  end\nend\n```\n\nIn conjunction with the following template:\n\n```html\n \n   \n     \n       \n          \n          Hello <%= generate_full_name(@first_name, @last_name) %>!  \n       \n     \n   \n \n```\n\nIn order to render the email you would then call: `FunctionTemplate.render(first_name: \"Alex\", last_name: \"Koutmos\")`","ref":"readme.html#using-functions-from-template-module"},{"type":"extras","title":"Using Components - README","doc":"**Static components**\n\nIn addition to compiling single MJML EEx templates, you can also create MJML partials and include them\nin other MJML templates AND components using the special `render_static_component` function. With the following\nmodules:\n\n```elixir\ndefmodule FunctionTemplate do\n  use MjmlEEx, mjml_template: \"component_template.mjml.eex\"\nend\n```\n\n```elixir\ndefmodule HeadBlock do\n  use MjmlEEx.Component\n\n  @impl true\n  def render(_opts) do\n    \"\"\"\n     \n       Hello world! \n        \n     \n    \"\"\"\n  end\nend\n```\n\nAnd the following template:\n\n```html\n \n  <%= render_static_component HeadBlock %>\n\n   \n     \n       \n          \n          Hello <%= generate_full_name(@first_name, @last_name) %>!  \n       \n     \n   \n \n```\n\nBe sure to look at the `MjmlEEx.Component` module for additional usage information as you can also pass options to your\ntemplate and use them when generating the partial string. One thing to note is that when using\n`render_static_component`, the data that is passed to the component must be defined at compile time. This means that you\ncannot use any assigns that would bee to be evaluated at runtime. For example, this would raise an error:\n\n```elixir\n \n  <%= render_static_component MyTextComponent, some_data: @some_data %>\n \n```\n\n**Dynamic components**\n\nIf you need to render your components dynamically, use `render_dynamic_component` instead and be sure to configure your\ntemplate module like below to generate the email HTML at runtime. First, you create your component, for example, `MyTemplate.CtaComponent.ex`:\n\n```elixir\ndef MyTemplate.CtaComponent do\n  use MjmlEEx.Component, mode: :runtime\n\n  @impl MjmlEEx.Component\n  def render(assigns) do\n    \"\"\"\n     \n       #{assigns[:call_to_action_text]} \n       #{assigns[:call_to_action_link]} \n     \n    \"\"\"\n  end\nend\n```\n\nthen, in your MJML template, insert it using the `render_dynamic_template_component` function:\n\n```html\n \n   \n     \n       \n          \n        <%= render_dynamic_component MyTemplate.CtaComponent %{call_to_action_text: \"Call to action text\",\n        call_to_action_link: \"#{@cta_link}\"} %>\n       \n     \n   \n \n```\n\nIn your `UserNotifier` module, or equivalent, you render your template, passing any assigns/data it expects:\n\n```Elixir\nWelcomeEmail.render(call_to_action_text: call_to_action_text, call_to_action_link: call_to_action_link)\n```","ref":"readme.html#using-components"},{"type":"extras","title":"Using Layouts - README","doc":"Often times, you'll want to create an Email skeleton or layout using MJML, and then inject your template into that\nlayout. MJML EEx supports this functionality which makes it really easy to have business branded emails application\nwide without having to copy and paste the same boilerplate in every template.\n\nTo create a layout, define a layout module like so:\n\n```elixir\ndefmodule BaseLayout do\n  use MjmlEEx.Layout, mjml_layout: \"base_layout.mjml.eex\"\nend\n```\n\nAnd an accompanying layout like so:\n\n```html\n \n   \n     Say hello to card \n      \n     \n        \n        \n        \n     \n   \n\n  <%= @inner_content %>\n \n```\n\nAs you can see, you can include assigns in your layout template (like `@padding`), but you also need to\ninclude a mandatory `@inner_content` expression. That way, MJML EEx knowns where to inject your template\ninto the layout. With that in place, you just need to tell your template module what layout to use (if\nyou are using a layout that is):\n\n```elixir\ndefmodule MyTemplate do\n  use MjmlEEx,\n    mjml_template: \"my_template.mjml.eex\",\n    layout: BaseLayout\nend\n```\n\nAnd your template file can contain merely the parts that you need for that particular template:\n\n```html\n  ...  \n```","ref":"readme.html#using-layouts"},{"type":"extras","title":"Using with Gettext - README","doc":"Similarly to Phoenix live/dead views, you can leverage Gettext to produce translated emails. To use Gettext, you will\nneed to have a Gettext module defined in your project (this should be created automatically for you when you create your\nPhoenix project via `mix phx.new MyApp`). Then your MjmlEEx module will look something like this:\n\n```elixir\ndefmodule MyApp.GettextTemplate do\n    import MyApp.Gettext\n\n    use MjmlEEx,\n      mjml_template: \"gettext_template.mjml.eex\",\n      mode: :compile\n  end\n```\n\nMake sure that you have the `import MyApp.Gettext` statement before the `use MjmlEEx` statement as you will get a\ncompiler error that the `gettext` function that is being called in the `gettext_template.mjml.eex` has not been defined.","ref":"readme.html#using-with-gettext"},{"type":"extras","title":"Configuration - README","doc":"MJML EEx has support for both the 1st party [NodeJS compiler](https://github.com/mjmlio/mjml) and the 3rd party\n[Rust compiler](https://github.com/jdrouet/mrml). By default, MJML EEx uses the Rust compiler as there is an\nElixir NIF built with [Rustler](https://github.com/rusterlium/rustler) that packages the Rust\nlibrary for easy use: [mjml_nif](https://github.com/adoptoposs/mjml_nif). By default the Rust compiler is used\nas it does not require you to have NodeJS available.\n\nIn order to use the NodeJS compiler, you can provide the following configuration in your `config.exs` file:\n\n```elixir\nconfig :mjml_eex, compiler: MjmlEEx.Compilers.Node\n```\n\nBe sure to check out the documentation for the `MjmlEEx.Compilers.Node` module as it also requires some\nadditional set up.","ref":"readme.html#configuration"},{"type":"extras","title":"Attribution - README","doc":"- The logo for the project is an edited version of an SVG image from the [unDraw project](https://undraw.co/)\n- The Elixir MJML library that this library builds on top of [MJML](https://github.com/adoptoposs/mjml_nif)\n- The Rust MRML library that provides the MJML compilation functionality [MRML](https://github.com/jdrouet/mrml)","ref":"readme.html#attribution"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}